#
# spec file for package python-pyahocorasick
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-pyahocorasick%{?psuffix}
Version:        2.2.0
Release:        1.1
Summary:        Library for exact or approximate multi-pattern string search
License:        BSD-3-Clause
URL:            https://github.com/WojciechMula/pyahocorasick
Source:         https://files.pythonhosted.org/packages/source/p/pyahocorasick/pyahocorasick-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
%if %{with test}
BuildRequires:  %{python_module pyahocorasick = %{version}}
%endif
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  python-rpm-macros
ExclusiveArch:  aarch64 loongarch64 ppc64 ppc64le riscv64 s390x x86_64
%python_subpackages

%description
pyahocorasick is a library for exact or approximate
multi-pattern string search, meaning that one can find
multiple key strings occurrences at once in some input text.  The
library provides an `ahocorasick` Python module that you can use as
a plain dict-like Trie or convert a Trie to an automaton for efficient
Aho-Corasick search.

It is implemented in C.

%prep
%autosetup -p1 -n pyahocorasick-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/ahocorasick*.so
%{python_sitearch}/pyahocorasick-%{version}.dist-info

%endif

%changelog
* Thu Jul 10 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.0:
  * Support python 3.13
  * Fix use of bool keyword in C23
  * Fix iter long fix leak
  * Drop python3.8 support
* Mon Feb 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Enable %%build section for test flavor
- Limit Python files matched in %%files section
* Mon Feb 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.1.0
  * Drop support for Python 3.6 and 3.7. Use older version for
    pre-built wheels. Note that it may work on these older version,
    we are just no longer supporting and testing these Python versions.
  * Add support for Python 3.12
- from version 2.0.0
  * Drop support for Python 2
  * Drop support for 32 bits OSes
  * Re-organize code such that sources are under src/, utilities
    under etc/ and tests are under tests/
  * Use pytest for testing and streamline tests to use a more conventional
    Python approach
  * Build more compatible Linux wheels using "ci-build-wheel"
- Restrict package to 64-bit architectures as 32-bit architectures
  are no longer supported upstream and the testsuite fails on these
- Split off tests into separate -test package
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.4.4 (2022-02-20)
  Minor rebuild to ensure Windows wheel documentation is correct ReST.
* Mon Mar 15 2021 Jan Engelhardt <jengelh@inai.de>
- Trim unspecific claims and metadata repetitions from description.
* Mon Mar 15 2021 Matej Cepl <mcepl@suse.com>
- Fix Summary to make rpmlint happy. That’s all we care about, isn’t it,
  to make rpmlint happy?
- Switch the test runner to pytest and skip two tests failing on
  big endian (gh#WojciechMula/pyahocorasick#142).
* Mon Mar 15 2021 Markéta Machová <mmachova@suse.com>
- Initial packaging (v1.4.1), needed by weblate
